package com.younike.system.mapper;

import java.util.List;
import com.younike.system.domain.OrderGoods;
import com.younike.system.domain.vo.OrderGoodsVo;

/**
 * 订单商品Mapper接口
 * 
 * @author elev
 * @date 2022-01-06
 */
public interface OrderGoodsMapper {
    /**
     * 查询订单商品
     * 
     * @param orderId 订单商品主键
     * @return 订单商品
     */
    OrderGoods selectOrderGoodsByOrderId(Long orderId);

    /**
     * 查询订单商品列表
     * 
     * @param orderGoods 订单商品
     * @return 订单商品集合
     */
    List<OrderGoods> selectOrderGoodsList(OrderGoods orderGoods);

    /**
     * 新增订单商品
     * 
     * @param orderGoods 订单商品
     * @return 结果
     */
    int insertOrderGoods(OrderGoods orderGoods);

    /**
     * 修改订单商品
     * 
     * @param orderGoods 订单商品
     * @return 结果
     */
    int updateOrderGoods(OrderGoods orderGoods);

    /**
     * 删除订单商品
     * 
     * @param orderId 订单商品主键
     * @return 结果
     */
    int deleteOrderGoodsByOrderId(Long orderId);

    /**
     * 批量删除订单商品
     * 
     * @param orderIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteOrderGoodsByOrderIds(Long[] orderIds);

    OrderGoodsVo getNowWeekDate(OrderGoodsVo orderGoodsVo);

    List<OrderGoodsVo> getOrderList(OrderGoodsVo orderGoodsVo);

    OrderGoodsVo getOrderInfo(OrderGoodsVo orderGoodsVo);
}
